set MEHL; # Menge der verschiedenen Mehlsorten
set PROD; # Menge der Mehlprodukte

param db{PROD} >=0;  # Deckungsbeitrag für die jeweilige Mehlsorte
param zusammensetzung{MEHL,PROD} >=0; # Zusammensetzung der Mehlprodukte aus dem Getreidemehl
param kapGetreide {MEHL} >=0;  # Kapazität der Getreidemehlsoren
param minpro{PROD} default 0;  # Mindestproduktion von Vollwertmehl
param kosten{PROD} >= 0;  # fixe Kosten, wenn Premiummehl produziert wird
param maxpro{j in PROD} = min{i in MEHL} (kapGetreide[i]/(if zusammensetzung[i,j]>0 then zusammensetzung[i,j] else 0.0001)); # maximale Menge an Mehlprodukt => wird berechnet

var xmehl{j in PROD} >= 0;  # Menge an Mehlprodukten
var xprodu{PROD} binary;        # 1, Mehlprodukt wird produziert, sonst 0

# Zielfunktion: maximaler Deckungsbeitrag: Deckungsbeitrag Mehl - fixe Kosten für Maschine
maximize deckungsbeitrag: sum{j in PROD} (db[j]*xmehl[j] - kosten[j]*xprodu[j]);

# Kapazität von Getreidemehl
s.t. Kapazität {i in MEHL}: sum{j in PROD} zusammensetzung[i,j]*xmehl[j] <= kapGetreide[i];

# Lower Bound für das Vollwertmehl
s.t. LB{j in PROD}: xmehl[j] >= minpro[j]*xprodu[j];

# Upper Bound für das Vollwertmehl
s.t. UB{j in PROD}: xmehl[j] <= maxpro[j]*xprodu[j];

